@@ -1,4 +1,4 @@
-# $Id: Audio.pm,v 1.10.2.2 2003/12/16 21:25:50 joern Exp $
+# $Id: Audio.pm,v 1.13 2004/04/25 16:01:58 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -9,6 +9,7 @@
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::Audio;
+use Locale::TextDomain qw (video.dvdrip);
 
 use base Video::DVDRip::Base;
 
@@ -165,4 +166,10 @@ sub pcm_ok {
 	return $ok;
 }
 
+sub is_passthrough {
+	my $self = shift;
+	return $self->tc_audio_codec eq 'ac3' or
+	       $self->tc_audio_codec eq 'pcm';
+}
+
 1;
