@@ -1,13 +1,15 @@
-# $Id: Progress.pm,v 1.23.2.1 2002/12/02 18:21:59 joern Exp $
+# $Id: Progress.pm,v 1.28 2004/04/11 23:36:20 joern Exp $
 
 #-----------------------------------------------------------------------
-# Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
+# Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
+# All Rights Reserved. See file COPYRIGHT for details.
 # 
 # This module is part of Video::DVDRip, which is free software; you can
 # redistribute it and/or modify it under the same terms as Perl itself.
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::GUI::Progress;
+use Locale::TextDomain qw (video.dvdrip);
 
 use base Video::DVDRip::GUI::Component;
 
@@ -41,7 +43,7 @@ sub build {
 	$progress->set_show_text (1);
 	$hbox->pack_start($progress, 1, 1, 0);
 
-	my $button = Gtk::Button->new_with_label (" Cancel ");
+	my $button = Gtk::Button->new_with_label (__"Cancel");
 	$button->signal_connect ("clicked", sub { $self->cancel } );
 
 	$hbox->pack_start($button, 0, 1, 0);
@@ -128,13 +130,15 @@ sub set_idle_label {
 	my $label;
 	if ( $project ) {
 		my $free = $project->get_free_diskspace;
-		$label = "Free diskspace: $free MB";
+		$label = __x("Free diskspace: {free} MB", free => $free);
 	} else {
 		$label = "";
 	}
 
 	$self->gtk_progress->set_format_string ($label);
-	
+
+	$project_comp->init_storage_values if $project_comp;
+
 	1;
 }
 
